@@ -41,12 +41,12 @@ Configuration file for Home Site Maker
 */
 
 
-$VERSION="homesitemaker-v0.4.7-1";                     // [STOP] Only for upgrading purporses
+$VERSION="homesitemaker-v0.4.8";                     // [STOP] Only for upgrading purporses
 $TITLE="Homesite Maker";                             // [EDIT] The title of your website
 $DESCRIPTION="The Homesite Maker project home page"; // [EDIT] A brief description of your website
 $URL="http://yoursite.org";                          // [REQUIRED] The URL used to serve your site
 
-$SKIN="white_clouds"; // [OPT] Available skins are rainbow, aqua, simple, black-simple, black-grey and white_clouds
+$SKIN="white_clouds"; // [OPT] Available skins are rainbow, aqua, simple, black-simple, black-grey, orange and white_clouds
 $ICONS="white_clouds";// [OPT] Available icon-set is white_clouds
 $ICON_SIZE1="32";     // [OPT] Available values are 64, 48, 32 and 22
 $ICON_SIZE2="48";     // [OPT] Available values are 64, 48, 32 and 22
