@@ -50,7 +50,7 @@ if ($id_session[num]==$num && $id_session[num]!="NULL" && $task!="edit")
   {
   echo "<tr><td class=\"text6\" colspan=\"2\">&nbsp;</td></tr>".
        "<tr><td class=\"text6\" colspan=\"2\"><hr color=$BLC size=$BLS></td></tr>".
-       "<tr><td class=\"text2b\" colspan=\"2\" align=\"right\">".
+       "<tr><td class=\"link1\" colspan=\"2\" align=\"right\">".
        "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type&user_section=1&num=$num&task=edit\">$TEXT008</a>&nbsp;&nbsp;".
        "</td></tr>";
   }
