@@ -277,9 +277,11 @@ if ($userfile_error > 0)
    exit;
    }
 
-include ("includes/system_config.php");
+include ("includes/graph_functions.php");
 include ("config_site.php");
 include ("db_connect.php");
+$filename=$_FILES['userfile']['name'][0];
+check_upload_max_filesize ($filename);
 $exist=file_exists("photos/albums/$id_album");
 $is_dir=is_dir("photos/albums/$id_album");
 if (!$exist || !$is_dir)mkdir("photos/albums/".$id_album,0777);
@@ -298,25 +300,23 @@ if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
    // and the variable CONVERT_PATH match with the path to this tool in your system
    if ( ($height > 1024) || ($width > 1024)  )
        {
-       $last_line=system("$CONVERT_PATH -geometry 1024x1024 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/high-$filename",$returned);
-       $last_line=system("$CONVERT_PATH -geometry 800x800 +profile \"*\" photos/albums/$id_album/high-$filename photos/albums/$id_album/medium-$filename",$returned);
-       $last_line=system("$CONVERT_PATH -geometry 640x640 +profile \"*\" photos/albums/$id_album/medium-$filename photos/albums/$id_album/low-$filename",$returned);
-       $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/low-$filename photos/albums/$id_album/thumbnail-$filename",$returned);
-       //images bigger than 1024 are not allowed
+       resize_image ($path_photo,1024,1024,"photos/albums/$id_album/high-$filename");
+       resize_image ("photos/albums/$id_album/high-$filename",800,800,"photos/albums/$id_album/medium-$filename");
+       resize_image ("photos/albums/$id_album/medium-$filename",640,640,"photos/albums/$id_album/low-$filename");
+       resize_image ("photos/albums/$id_album/low-$filename",70,70,"photos/albums/$id_album/thumbnail-$filename");
        unlink ("photos/albums/$id_album/$filename");
        } else if ( ($height > 800) || ($width > 800)  )
                  {
-                 $last_line=system("$CONVERT_PATH -geometry 800x800 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/medium-$filename",$returned); 
-                 $last_line=system("$CONVERT_PATH -geometry 640x640 +profile \"*\" photos/albums/$id_album/medium-$filename photos/albums/$id_album/low-$filename",$returned); 
-                 $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/low-$filename photos/albums/$id_album/thumbnail-$filename",$returned);
-
+                 resize_image ($path_photo,800,800,"photos/albums/$id_album/medium-$filename");
+                 resize_image ("photos/albums/$id_album/medium-$filename",640,640,"photos/albums/$id_album/low-$filename");
+                 resize_image ("photos/albums/$id_album/low-$filename",70,70,"photos/albums/$id_album/thumbnail-$filename");
                  } else if ( ($height > 640) || ($width > 640)  )
                            {
-                           $last_line=system("$CONVERT_PATH -geometry 640x640 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/low-$filename",$returned);
-                           $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/low-$filename photos/albums/$id_album/thumbnail-$filename",$returned);
+                           resize_image ($path_photo,640,640,"photos/albums/$id_album/low-$filename");
+                           resize_image ("photos/albums/$id_album/low-$filename",70,70,"photos/albums/$id_album/thumbnail-$filename");
                            } else if ( ($height > 70) || ($width > 70)  )
                                      {
-                                     $last_line=system("$CONVERT_PATH -geometry 70x70 +profile \"*\" photos/albums/$id_album/$filename photos/albums/$id_album/thumbnail-$filename",$returned);
+                                     resize_image ($path_photo,70,70,"photos/albums/$id_album/thumbnail-$filename");
                                      } else copy ( "photos/albums/$id_album/$filename", "photos/albums/$id_album/thumbnail-$filename");
 
     /*
@@ -452,6 +452,7 @@ global $LANGUAGE;
 include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
 include ("includes/config_site.php");
 include ("includes/system_config.php");
+include ("includes/graph_functions.php");
 include ("db_connect.php");
 
 if (strlen($intro_text) > 0) { $intro='YES';} else $intro='NO';
@@ -499,9 +500,10 @@ If the directory already exists, only photos and thumbnails should be added.
 $exist=file_exists("photos/infos/$id_info");
 $is_dir=is_dir("photos/infos/$id_info");
 if (!$exist || !$is_dir)mkdir("photos/infos/".$id_info,0777);
+$filename=$_FILES['userfile']['name'][0];
+check_upload_max_filesize ($filename);
 if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
    {
-   $filename=$_FILES['userfile']['name'][0];
    $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
    $filename=str_replace($pattern,"_",$filename);
    $path_photo="photos/infos/$id_info/$filename";
@@ -514,11 +516,8 @@ if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
    mysql_query ("INSERT INTO info_album (id_info,filename,height,width) values ('$id_info','$filename','$height','$width')");
 
    // If uploaded files are bigger than 200x200 pixels, then a 200x200 thumbnail should be generated.
-   if ( ($height > 200) || ($width > 200)  )
-      {
-      system("$CONVERT_PATH -geometry 200x200 +profile \"*\" photos/infos/$id_info/$filename photos/infos/$id_info/thumbnail-$filename");
-      } else copy ( "photos/infos/$id_info/$filename", "photos/infos/$id_info/thumbnail-$filename");
-    }
+   resize_image ($path_photo,200,200,"photos/infos/$id_info/thumbnail-$filename");
+   }
 
    for ( $i = 0; $i<$num_photos; $i++) // delete selected photos
        {
@@ -581,6 +580,7 @@ include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
 include ("config_site.php");
 include ("db_connect.php");
 include ("includes/system_config.php");
+include ("includes/graph_functions.php");
 
 if ($modified_by=="anonymous") {$id_author=1;}
 
@@ -614,6 +614,9 @@ Also the directory on where the photos and thumbnails will be saved, should be c
 If the directory already exists, only photos and thumbnails should be added.
 */
 
+$filename=$_FILES['userfile']['name'][0];
+check_upload_max_filesize ($filename);
+
 // return the last id_info generated in the last INSERT query
 $id_info=mysql_insert_id ();
 $exist=file_exists("photos/infos/$id_info");
@@ -621,24 +624,14 @@ $is_dir=is_dir("photos/infos/$id_info");
 if (!$exist || !$is_dir)mkdir("photos/infos/".$id_info,0777);
 if (is_uploaded_file($_FILES['userfile']['tmp_name'][0]))
    {
-   $filename=$_FILES['userfile']['name'][0];
    $pattern = array(" ", "&", "?", "|", "<", ">", "(", ")","", "");
    $filename=str_replace($pattern,"_",$filename);
    $path_photo="photos/infos/$id_info/$filename";
    move_uploaded_file($_FILES['userfile']['tmp_name'][0], $path_photo);
-   $size=getimagesize($path_photo);
-   $width=$size[0];
-   $height=$size[1];
-
-   // Once the photo is already uploaded, the entry should be added to the album table.
    mysql_query ("INSERT INTO info_album (id_info,filename,height,width) values ('$id_info','$filename','$height','$width')");
-
-   // If uploaded files are bigger than 200x200 pixels, then a 200x200 thumbnail should be generated.
-   if ( ($height > 200) || ($width > 200)  )
-      {
-      system("$CONVERT_PATH -geometry 200x200 +profile \"*\" photos/infos/$id_info/$filename photos/infos/$id_info/thumbnail-$filename"); 
-      } else copy ( "photos/infos/$id_info/$filename", "photos/infos/$id_info/thumbnail-$filename");
-    }
+   // create a thumbnail image with the maximum width, or height, of 200 pixels or leave the image with the original size.
+   resize_image ($path_photo,200,200,"photos/infos/$id_info/thumbnail-$filename");
+   }
 if ($choice==$SUBMIT)
    {
    echo "<span class=\"text1\"><center><br><br>$TEXT015</center><br><br>";
@@ -680,7 +673,7 @@ return 0;
 function dbwa_add_user ($new_nick, $password, $password_check, $email, $real_name, $level) {
 include ("config_site.php");
 include ("db_connect.php");
-include ("includes/system_config.php");
+include ("includes/graph_functions.php");
 
 $check_nickname=mysql_query("SELECT nick FROM users WHERE nick='$new_nick'", $db);
 $n=mysql_num_rows ($check_nickname);
@@ -722,15 +715,7 @@ If the directory already exists, only photos and thumbnails should be added.
      $filename=str_replace($pattern,"_",$filename);
      $path_user_photo="photos/users/$id_user/$filename";
      move_uploaded_file($_FILES['user_photo']['tmp_name'][0], $path_user_photo);
-     $size=getimagesize($path_user_photo);
-     $width=$size[0];
-     $height=$size[1];
-     
-     // If uploaded file is bigger than 70x100 pixels an small image is generated
-     if ( ($height > 100) || ($width > 70)  )
-        {
-        system("$CONVERT_PATH -geometry 70x100 +profile \"*\" $path_user_photo $path_user_photo");
-        } else copy ( "$filename", "$filename");
+     resize_image ($path_user_photo,70, 100,$path_user_photo);
      }
   }
 return 0;
@@ -741,7 +726,8 @@ global $LANGUAGE;
 include ("includes/languages/".$LANGUAGE."/homesite-includes-dbwa.php");
 include ("config_site.php");
 include ("db_connect.php");
-include ("includes/system_config.php");
+include ("includes/graph_functions.php");
+
 
 $check_nickname=mysql_query("SELECT nick FROM users WHERE nick='$new_nick'", $db);
 $n=mysql_num_rows ($check_nickname);
@@ -784,15 +770,7 @@ If the directory already exists, only photos and thumbnails should be added.
      $filename=str_replace($pattern,"_",$filename);
      $path_user_photo="photos/users/$id_user/$filename";
      move_uploaded_file($_FILES['user_photo']['tmp_name'][0], $path_user_photo);
-     $size=getimagesize($path_user_photo);
-     $width=$size[0];
-     $height=$size[1];
-
-     // If uploaded file is bigger than 70x100 pixels, then an small image is generated
-     if ( ($height > 100) || ($width > 70)  )
-        {
-        system("$CONVERT_PATH -geometry 70x100 +profile \"*\" $path_user_photo $path_user_photo");
-        } else copy ( "$filename", "$filename");
+     resize_image ($path_user_photo,70, 100,$path_user_photo);
      }
   }
 return 0;
@@ -802,7 +780,7 @@ return 0;
 function dbwa_edit_user ($id_user, $new_nick, $password, $password_check, $real_name, $email, $level) {
 include ("config_site.php");
 include ("db_connect.php");
-include ("includes/system_config.php");
+include ("includes/graph_functions.php");
 
 $check_nickname=mysql_query("SELECT nick, password FROM users WHERE nick='$new_nick' AND id_user!='$id_user'", $db);
 $n=mysql_num_rows ($check_nickname);
@@ -845,15 +823,7 @@ if ( $user_form == 0 ) // check if nickname is unused and password is correct
      $filename=str_replace($pattern,"_",$filename);
      $path_user_photo="photos/users/$id_user/$filename";
      move_uploaded_file($_FILES['user_photo']['tmp_name'][0], $path_user_photo);
-     $size=getimagesize($path_user_photo);
-     $width=$size[0];
-     $height=$size[1];
-
-     // If the uploaded file is bigger than 70x100 pixels, then generate a 70x100 image
-     if ( ($height > 100) || ($width > 70)  )
-        {
-        system("$CONVERT_PATH -geometry 70x100 +profile \"*\" $path_user_photo $path_user_photo");
-        } else copy ( "$filename", "$filename");
+     resize_image ($path_user_photo,70, 100,$path_user_photo);
      }
   }
 return 0;
