@@ -113,4 +113,7 @@ $TEXT057="Escriu aqu&iacute; el teu comentari !";
 $TEXT058="Escriu aqu&iacute; el teu texte !";
 $TEXT059="C&oacute;dig de seguretat: ";
 $TEXT060="Introdueix el c&oacute;dig de seguretat: ";
+$TEXT061="El tamany m&aacute;ximo de fitxer adm&eacute;s pel servidor es:";
+$TEXT062="Afegir a Bloglines";
+$TEXT063="Afegir a Google";
 ?>
