@@ -108,4 +108,7 @@ $TEXT057="Write your comment here !";
 $TEXT058="Write your text here !";
 $TEXT059="Secure code: ";
 $TEXT060="Type secure code: ";
+$TEXT061="The maximum file size allowed by the server is:";
+$TEXT062="Subscribe with Bloglines";
+$TEXT063="Add to Google";
 ?>
