@@ -107,4 +107,7 @@ $TEXT057="Escribe aqu&iacute; tu comentario !";
 $TEXT058="Escribe aqu&iacute; tu text !";
 $TEXT059="C&oacute;digo de seguridad: ";
 $TEXT060="Introduce el c&oacute;digo de seguridad: ";
+$TEXT061="El tama&ntilde;o m&aacute;ximo de fichero admitido por el servidor es de:";
+$TEXT062="Subscribirme con Bloglines";
+$TEXT063="A&ntilde;adir a Google";
 ?>
