@@ -185,7 +185,8 @@ if ($STATS!="NO")
        }
    if ($news>0) echo "<br><hr color=\"$LPTLC\" size=\"$LPTLS\">".
                      "<center><br><span class=\"text1b\">$LTEXT1009<br></center>".
-                     "<center><a href=\"$URL/index.php?top_tab=$top_tab&section_type=$section_type&task=rss_feeds&num=$num\"><img border=0 src=\"images/logos/rss20.png\"></a></span></center>";
+                     "<center><a href=\"index.php?top_tab=$top_tab&section_type=$section_type&task=rss_feeds&num=$num\">".
+                     "<img border=0 src=\"images/logos/rss20.png\"></a></span></center>";
 
 echo "</td>";
 ?>
