@@ -28,21 +28,8 @@ Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
 */
 
 
-//
-// Configuration file for HomeSite M.A.K.E.R
-//
+// This file was previously used to set the path to the 'convert' tool.
+// The 'convert' tool was used to resize the uploaded images, but it was removed when the Homesitemaker 0.4.8 was released.
+// The file has not been removed from the sources because may be used again in the future.
 
-
-// PATH to the CONVERT utility from the ImageMagick toolkit
-// Use one of the following acording to your system
-// If your OS don't appear in the examples, use "whereis" command 
-// to find the location of the convert binary
-//
-// FreeBSD 5.x /usr/local/bin/convert
-// Slacakware 9.0 /usr/X11R6/bin/convert
-// Fedora Core 3, SuSe Linux 9.2, 9.3 and OpenSuSE 10.0 /usr/bin/convert
-
-$CONVERT_PATH="/usr/bin/convert";
-#$CONVERT_PATH="/usr/local/bin/convert"; 
-#$CONVERT_PATH="/usr/X11R6/bin/convert";
 ?>
