@@ -26,10 +26,8 @@ http://homesitemaker.no-ip.org
 
 -->
 
-<!-- NOMBRE ARCHIVO:   info.php                              -->
-<!-- AUTOR:            Marcos Martinez Jimenez               -->
-<!-- SITE:             Homesitemaker                         -->
-
+<!-- FILENAME:   info.php                              -->
+<!-- AUTOR:      Marcos Martinez Jimenez               -->
 
 
 <table border="0" width="90%" align="center">
@@ -156,10 +154,10 @@ if ($id_session[num] == $num && $task=="edit" && $id_session[num] != "" && $curr
    if ($num_photos>=1)
       {
       echo "<tr><td class=\"text1\" colspan=4>$IEM005<br><br></td></tr>".
-           "<tr><td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$PTEM001</td>".
-           "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$PTEM002</td>".
-           "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$PTEM003</td>".
-           "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$PTEM004</td></tr>";
+           "<tr><td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM001</td>".
+           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM002</td>".
+           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM003</td>".
+           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM004</td></tr>";
       }
 
 
@@ -167,18 +165,20 @@ if ($id_session[num] == $num && $task=="edit" && $id_session[num] != "" && $curr
    $n=0;
    while ($album_result=mysql_fetch_array($album_query))
          {
-         echo "<tr><td align=\"center\" bgcolor=\"#62acfe\">".
+         echo "<tr><td align=\"center\" bgcolor=$TNED1>".
               "<INPUT type=\"checkbox\" name=\"id_photo[$n]\" value=\"".$album_result["id_photo"]."\"></td>".
-              "<td class=\"text2\" align=\"center\" bgcolor=\"#62acdd\">".$album_result["filename"]."</td>".
-              "<td class=\"text2\" align=\"center\" bgcolor=\"#62acfe\">".$album_result["id_photo"]."</td>".
-              "<td bgcolor=\"#62acdd\">".
+              "<td class=\"text2\" align=\"center\" bgcolor=$TNED2>".$album_result["filename"]."</td>".
+              "<td class=\"text2\" align=\"center\" bgcolor=$TNED1>".$album_result["id_photo"]."</td>".
+              "<td bgcolor=$TNED2>".
               "<img src=\"photos/infos/".$info_result["id_info"]."/thumbnail-".$album_result["filename"]."\">".
               "</td></tr>";
          $n++;
          }
+   $upload_max_filesize=ini_get('upload_max_filesize');
    echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
         "<tr><td class=\"text2b\" colspan=4><br>$IEM006</td></tr>".
         "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+        "<tr><td class=\"text1\" colspan=4>$IEM007 $upload_max_filesize<br><br></td></tr>".
         "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
         "&nbsp;<input type=\"submit\" value=\"$IEBM002\"></input><br></td></tr>".
         "</form>";
@@ -218,10 +218,10 @@ if ($id_session[num] == $num && $task=="editGUI" && $id_session[num] != "" && $c
    if ($num_photos>=1)
       {
       echo "<tr><td class=\"text1\" colspan=4>$IEM005<br><br></td></tr>".
-           "<tr><td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$PTEM001</td>".
-           "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$PTEM002</td>".
-           "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$PTEM003</td>".
-           "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$PTEM004</td></tr>";
+           "<tr><td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM001</td>".
+           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM002</td>".
+           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED1>$PTEM003</td>".
+           "<td class=\"text1b\" align=\"center\" bgcolor=$TNED2>$PTEM004</td></tr>";
       }
 
 
@@ -229,18 +229,20 @@ if ($id_session[num] == $num && $task=="editGUI" && $id_session[num] != "" && $c
    $n=0;
    while ($album_result=mysql_fetch_array($album_query))
          {
-         echo "<tr><td align=\"center\" bgcolor=\"#62acfe\">".
+         echo "<tr><td align=\"center\" bgcolor=$TNED1>".
               "<INPUT type=\"checkbox\" name=\"id_photo[$n]\" value=\"".$album_result["id_photo"]."\"></td>".
-              "<td class=\"text2\" align=\"center\" bgcolor=\"#62acdd\">".$album_result["filename"]."</td>".
-              "<td class=\"text2\" align=\"center\" bgcolor=\"#62acfe\">".$album_result["id_photo"]."</td>".
-              "<td bgcolor=\"#62acdd\">".
+              "<td class=\"text2\" align=\"center\" bgcolor=$TNED2>".$album_result["filename"]."</td>".
+              "<td class=\"text2\" align=\"center\" bgcolor=$TNED1>".$album_result["id_photo"]."</td>".
+              "<td bgcolor=$TNED2>".
               "<img src=\"photos/infos/".$info_result["id_info"]."/thumbnail-".$album_result["filename"]."\">".
               "</td></tr>";
          $n++;
          }
+   $upload_max_filesize=ini_get('upload_max_filesize');
    echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
         "<tr><td class=\"text2b\" colspan=4><br>$IEM006</td></tr>".
         "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+        "<tr><td class=\"text1\" colspan=4>$IEM007 $upload_max_filesize<br><br></td></tr>".
         "<tr><td class=\"text1\"colspan=4><br>&nbsp;<br></td></tr>".
         "</form>";
    }
