@@ -310,9 +310,11 @@ if ($task=="edit" && $current_user["level"] >= "50" || ($task=="edit" && ($id_vi
 
    if ($info_result["status"]==0 )
       {
+      $upload_max_filesize=ini_get('upload_max_filesize');
       echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
-           "<tr><td class=\"text2b\" colspan=4><br>Attach Photo:</td></tr>".
+           "<tr><td class=\"text2b\" colspan=4><br>$TEXT024:</td></tr>".
            "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+           "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
            "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
            "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
            "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT023\"></input><br></td></tr>".
@@ -320,9 +322,11 @@ if ($task=="edit" && $current_user["level"] >= "50" || ($task=="edit" && ($id_vi
       }
 if ($info_result["status"]==1 || $info_result["status"]==2)
       {
+      $upload_max_filesize=ini_get('upload_max_filesize');
       echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
            "<tr><td class=\"text2b\" colspan=4><br>$TEXT024:</td></tr>".
            "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+           "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
            "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
            "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
            "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT026\"></input><br></td></tr>".
@@ -410,9 +414,11 @@ if ($task=="editGUI" && $current_user["level"] >= "50" || ($task=="editGUI" && (
 
    if ($info_result["status"]==0 )
       {
+      $upload_max_filesize=ini_get('upload_max_filesize');
       echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
-           "<tr><td class=\"text2b\" colspan=4><br>Attach Photo:</td></tr>".
+           "<tr><td class=\"text2b\" colspan=4><br>$TEXT024:</td></tr>".
            "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+           "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
            "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
            "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
            "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT023\"></input><br></td></tr>".
@@ -420,9 +426,11 @@ if ($task=="editGUI" && $current_user["level"] >= "50" || ($task=="editGUI" && (
       }
 if ($info_result["status"]==1 || $info_result["status"]==2)
       {
+      $upload_max_filesize=ini_get('upload_max_filesize');
       echo "<input type=\"hidden\" name=\"num_photos\" value=\"$num_photos\">".
            "<tr><td class=\"text2b\" colspan=4><br>$TEXT024:</td></tr>".
            "<tr><td class=\"text1\" colspan=4><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+           "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
            "<tr><td class=\"text1\"colspan=4 align=\"center\"><br>".
            "<input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
            "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT026\"></input><br></td></tr>".
@@ -434,6 +442,7 @@ if ($info_result["status"]==1 || $info_result["status"]==2)
 // If the user was loged and selects the edit option (task==edit), then he can modify the whole section.
 if ($id_session[num] == $num && $task=="submit" && $id_session[num] != "")
    {
+   $upload_max_filesize=ini_get('upload_max_filesize');
    echo "<form enctype=\"multipart/form-data\" method=\"post\"".
         " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
         "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
@@ -454,6 +463,7 @@ if ($id_session[num] == $num && $task=="submit" && $id_session[num] != "")
         "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
         "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
         "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+        "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
         "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
         "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
         "</form>";
@@ -462,6 +472,7 @@ if ($id_session[num] == $num && $task=="submit" && $id_session[num] != "")
 // If the user was loged and selects the edit option (task==editGUI), then he can modify the whole section.
 if ($id_session[num] == $num && $task=="submitGUI" && $id_session[num] != "")
    {
+   $upload_max_filesize=ini_get('upload_max_filesize');
    echo "<form enctype=\"multipart/form-data\" method=\"post\"".
         " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
         "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
@@ -489,6 +500,7 @@ if ($id_session[num] == $num && $task=="submitGUI" && $id_session[num] != "")
         "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
         "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
         "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+        "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
         "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
         "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
         "</form>";
@@ -498,6 +510,7 @@ if ($id_session[num] == $num && $task=="submitGUI" && $id_session[num] != "")
 // If the user in not loged and selects the submit option (task==submit), then he can modify the whole section.
 if ($task=="anonymous_submit")
    {
+   $upload_max_filesize=ini_get('upload_max_filesize');
    echo "<form enctype=\"multipart/form-data\" method=\"post\"".
         " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
         "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
@@ -518,6 +531,7 @@ if ($task=="anonymous_submit")
         "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
         "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
         "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+        "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
         "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
         "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
         "</form>";
@@ -526,6 +540,7 @@ if ($task=="anonymous_submit")
 // If the user in not loged and selects the edit option (task==submitGUI), then he can modify the whole section.
 if ($task=="anonymous_submitGUI")
    {
+   $upload_max_filesize=ini_get('upload_max_filesize');
    echo "<form enctype=\"multipart/form-data\" method=\"post\"".
         " action=\"index.php?top_tab=$top_tab&section_type=$section_type&num=$num\">".
         "<input type=\"hidden\" name=\"dbwa\" value=\"dbwa_add_info\">".
@@ -553,6 +568,7 @@ if ($task=="anonymous_submitGUI")
         "<tr><td class=\"text1\" colspan=2>$TEXT017<br><br></td></tr>".
         "<tr><td class=\"text2b\" colspan=2><br>$TEXT024:</td></tr>".
         "<tr><td class=\"text1\" colspan=2><input type=\"file\" name=\"userfile[]\" size=40>&nbsp;</input></td></tr>".
+        "<tr><td class=\"text1\" colspan=4>$TEXT061 $upload_max_filesize<br><br></td></tr>".
         "<tr><td class=\"text1\"colspan=2 align=\"center\"><br><input type=\"submit\" name=\"choice\" value=\"$TEXT025\"></input>".
         "&nbsp;<input type=\"submit\" name=\"choice\" value=\"$TEXT001\"></input><br></td></tr>".
         "</form>";
@@ -572,20 +588,20 @@ if ($id_session[num] == $num && $task=="pending" && $id_session[num] != "")
       if ($num_pending_news>0)
          {
          echo "<tr><td class=\"text1\" colspan=5><br>$TEXT029<br><br></td></tr>".
-              "<tr><td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$TEXT019</td>".
-              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$TEXT030</td>".
-              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$TEXT015</td>".
-              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acdd\">$TEXT014</td>".    
-              "<td class=\"text1b\" align=\"center\" bgcolor=\"#62acfe\">$TEXT031</td></tr>";
+              "<tr><td class=\"text1b\" align=\"center\" bgcolor=$ASH>$TEXT019</td>".
+              "<td class=\"text1b\" align=\"center\" bgcolor=$ASH>$TEXT030</td>".
+              "<td class=\"text1b\" align=\"center\" bgcolor=$ASH>$TEXT015</td>".
+              "<td class=\"text1b\" align=\"center\" bgcolor=$ASH>$TEXT014</td>".    
+              "<td class=\"text1b\" align=\"center\" bgcolor=$ASH>$TEXT031</td></tr>";
          while ($pending_news=mysql_fetch_array($pending_news_query))
                {
                $user_query=mysql_query("SELECT nick FROM users WHERE id_user='".$pending_news["id_author"]."'", $db);
                $user_result=mysql_fetch_array($user_query);
-               echo "<tr><td class=\"text2\"align=\"center\" bgcolor=\"#62acfe\">".
+               echo "<tr><td class=\"link0\"align=\"center\" bgcolor=$ASF>".
                     "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
                     "&num=$num&task=delete&id_info=".$pending_news["id_info"]."\">$TEXT019</td>".
-                    "<td class=\"text2\" align=\"center\" bgcolor=\"#62acdd\">".$pending_news["id_info"]."</td>".
-                    "<td class=\"text2\" align=\"center\" bgcolor=\"#62acfe\">";
+                    "<td class=\"text1\" align=\"center\" bgcolor=$ASF>".$pending_news["id_info"]."</td>".
+                    "<td class=\"link0\" align=\"center\" bgcolor=$ASF>";
                switch ($EDITOR) {
                case "text-html":
                   echo "<a href=\"index.php?top_tab=$top_tab&section_type=$section_type".
@@ -603,8 +619,8 @@ if ($id_session[num] == $num && $task=="pending" && $id_session[num] != "")
                        "&num=$num&task=editGUI&id_info=".$pending_news["id_info"]."\">".$pending_news["headline"]."&nbsp;(GUI)</a></td>";
                break;
                }
-                  echo  "<td class=\"text2\" align=\"center\" bgcolor=\"#62acdd\">".$user_result["nick"]."</td>".
-                        "<td class=\"text2\" align=\"center\" bgcolor=\"#62acfe\">".$pending_news["posted"]."</td>".
+                  echo  "<td class=\"text1\" align=\"center\" bgcolor=$ASF>".$user_result["nick"]."</td>".
+                        "<td class=\"text1\" align=\"center\" bgcolor=$ASF>".$pending_news["posted"]."</td>".
                         "</td></tr>";
                $n++;
                }
@@ -1101,10 +1117,13 @@ if ($task=="rss_feeds")
            $section_name_str = "TAB_"."$tab"."$section";
            if ($$section_type_str == "news") // Shows the RSS logo only if one news section exists
               {
-              echo "<tr><td class=\"link1\" colspan=\"4\">&nbsp;&nbsp;&nbsp;&nbsp;".
-                   "<a href=\"rss/news$tab$section.rss\">".
-                   "<img src=\"images/logos/rss_icon.png\" border=\"0\" align=\"middle\">&nbsp;&nbsp;".$$section_name_str.
-                   "</a>".
+              echo "<tr><td class=\"link2\" colspan=\"4\">&nbsp;&nbsp;&nbsp;&nbsp;".
+                   "<a href=\"rss/news$tab$section.rss\">".$$section_name_str."&nbsp;&nbsp;".
+                   "<img src=\"images/logos/rss_icon.png\" border=\"0\" align=\"top\">&nbsp;&nbsp;</a>".
+                   "</a>&nbsp;<a href=\"http://www.bloglines.com/sub/$URL/rss/news$tab$section.rss\">".
+                   "<img align=\"top\" src=\"images/logos/sub_modern10.png\" border=\"0\" alt=$TEXT062></a>".
+                   "&nbsp;&nbsp;<a href=\"http://fusion.google.com/add?feedurl=$URL/rss/news$tab$section.rss\">".
+                   "<img src=\"images/logos/add-to-google-plus.png\" width=\"104\" height=\"17\" border=\"0\" alt=$TEXT063></a>".
                    "</td></tr>";
               }
            }
